progress

package
v1.4.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 6, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Step

func Step(msg string)

Step prints a progress step message.

Types

type Spinner

type Spinner struct {
	// contains filtered or unexported fields
}

Spinner displays a simple animated spinner with a message.

func Start

func Start(msg string) *Spinner

Start begins a spinner with the given message.

func (*Spinner) Stop

func (s *Spinner) Stop()

Stop stops the spinner and marks it as complete.

func (*Spinner) StopFail

func (s *Spinner) StopFail()

StopFail stops the spinner and marks it as failed.

Jump to